/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jclouds.aliyun.ecs.domain;

import com.google.common.base.MoreObjects;
import com.google.common.base.Objects;

import java.beans.ConstructorProperties;

public class AllocatePublicIpAddressRequest extends Request {

   private final String ipAddress;

   @ConstructorProperties({ "RequestId", "IpAddress" })
   public AllocatePublicIpAddressRequest(String requestId, String ipAddress) {
      super(requestId);
      this.ipAddress = ipAddress;
   }

   public String getInstanceId() {
      return ipAddress;
   }

   @Override
   public boolean equals(Object o) {
      if (this == o)
         return true;
      if (o == null || getClass() != o.getClass())
         return false;
      if (!super.equals(o))
         return false;
      AllocatePublicIpAddressRequest that = (AllocatePublicIpAddressRequest) o;
      return Objects.equal(ipAddress, that.ipAddress);
   }

   @Override
   public int hashCode() {
      return Objects.hashCode(super.hashCode(), ipAddress);
   }

   @Override
   public String toString() {
      return MoreObjects.toStringHelper(this).add("ipAddress", ipAddress).toString();
   }
}
