/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jclouds.aliyun.ecs.functions;

import com.google.common.base.Function;
import com.google.common.base.Joiner;
import com.google.common.collect.Iterables;

import javax.inject.Singleton;
import java.util.Arrays;

import static com.google.common.base.Preconditions.checkArgument;
import static com.google.common.base.Preconditions.checkNotNull;

/**
 * Takes an array of string and return a "["s1", "s2", … "sN"]"
 */
@Singleton
public class ArrayToCommaSeparatedString implements Function<Object, String> {
   @Override
   public String apply(Object input) {
      checkArgument(checkNotNull(input, "input") instanceof String[], "This function is only valid for array of Strings!");
      String[] names = (String[]) input;

      String arrayToCommaSeparatedString = Joiner.on(",")
              .join(Iterables.transform(Arrays.asList(names), new Function<String, String>() {
                 @Override
                 public String apply(String s) {
                    return new StringBuilder(s.length() + 1).append('"').append(s).append('"').toString();
                 }
              }));
      return String.format("[%s]", arrayToCommaSeparatedString);
   }

}
